@@ -1,4 +1,5 @@
 """Checking functionality."""
+
 from __future__ import annotations
 
 import contextlib
@@ -26,6 +27,14 @@ import docutils.utils
 
 from . import _docutils, _extras, _sphinx, config, inline_config, types
 
+try:
+    import yaml
+
+    yaml_imported = True
+except ImportError:
+    yaml_imported = False
+
+
 logger = logging.getLogger(__name__)
 
 
@@ -420,10 +429,14 @@ class _CheckTranslator(docutils.nodes.NodeVisitor):
 
         directive_line = _get_code_block_directive_line(node, self.source)
         if directive_line is None:
-            logger.error(
-                "Could not find line for literal block directive. Source: '%s' at line %s",
+            logger.warning(
+                "Could not find line for literal block directive. "
+                "This could be due to an indented code block. "
+                "This message only warns about the missing line number "
+                "and is no error of itself. "
+                "Source: '%s'%s",
                 self.source_origin,
-                node.line,
+                f" at line {node.line}" if node.line is not None else "",
             )
             return
 
@@ -669,6 +682,28 @@ class CodeBlockChecker:
                 source_origin=self.source_origin, line_number=int(line_number), message=message
             )
 
+    def check_yaml(self, source_code: str) -> types.YieldedLintError:
+        """Check YAML source for syntax errors.
+
+        :param source: JSON source code to check
+        :return: :py:obj:`None`
+        :yield: Found issues
+        """
+        if not yaml_imported:
+            logger.debug("PyYAML is not installed, ignoring YAML source.")
+            return
+        logger.debug("Check YAML source.")
+        try:
+            yaml.safe_load(source_code)
+        except yaml.error.YAMLError as exception:
+            message = f"{exception}"
+            found = EXCEPTION_LINE_NO_REGEX.search(message)
+            line_number = int(found.group(1)) if found else 0
+
+            yield types.LintError(
+                source_origin=self.source_origin, line_number=int(line_number), message=message
+            )
+
     def check_xml(self, source_code: str) -> types.YieldedLintError:
         """Check XML source for syntax errors.
 
